Environment Variables — gc3pie development (SVN $Revision$) documentation

### Navigation

- index
- modules |
- next |
- previous |
- gc3pie development (SVN $Revision$) documentation »
- User Documentation »

# Environment Variables

The following environmental variables affect GC3Pie operations.

GC3PIE_CONF

> Path to an additional configuration file, that is read upon initialization of GC3Pie. If undefined or empty, no additional configuration file is loaded.

GC3PIE_NO_CATCH_ERRORS

> When set to any value, GC3Pie will not act on unexpected/generic errors (by default, ignoring them) and instead propagates the exception all the way up to top-level. This facilitates running GC3Pie scripts in a debugger and inspecting the code when some unexpected error condition happens.

### Navigation

- index
- modules |
- next |
- previous |
- gc3pie development (SVN $Revision$) documentation »
- User Documentation »